cli

package
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 18, 2026 License: MIT Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var BuildTime string

BuildTime is optionally set at build time via ldflags targeting the main package.

var Version = "0.0.4"

Version is the current version of the CLI, defaulting to the version from gen.yaml. It can be overridden at build time via ldflags targeting the main package, which propagates the value here (see cmd/compass/main.go):

go build -ldflags "-X main.version=x.y.z" ./cmd/compass

Functions

func Execute

func Execute() error

func NewRootCommand

func NewRootCommand() (*cobra.Command, error)

NewRootCommand creates and returns the root command. This is exported for testing purposes to allow in-process command execution.

Types

This section is empty.

Directories

Path Synopsis
Package risk holds hand-written CLI commands that don't come from the OpenAPI spec.
Package risk holds hand-written CLI commands that don't come from the OpenAPI spec.

Jump to