Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var BuildTime string
BuildTime is optionally set at build time via ldflags targeting the main package.
var Version = "0.0.4"
Version is the current version of the CLI, defaulting to the version from gen.yaml. It can be overridden at build time via ldflags targeting the main package, which propagates the value here (see cmd/compass/main.go):
go build -ldflags "-X main.version=x.y.z" ./cmd/compass
Functions ¶
func NewRootCommand ¶
NewRootCommand creates and returns the root command. This is exported for testing purposes to allow in-process command execution.
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package risk holds hand-written CLI commands that don't come from the OpenAPI spec.
|
Package risk holds hand-written CLI commands that don't come from the OpenAPI spec. |
Click to show internal directories.
Click to hide internal directories.